Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'jpa/plugins/org.eclipse.jpt.jpa.ui/src/org/eclipse/jpt/jpa/ui/details/JpaDetailsProvider.java')
-rw-r--r--jpa/plugins/org.eclipse.jpt.jpa.ui/src/org/eclipse/jpt/jpa/ui/details/JpaDetailsProvider.java38
1 files changed, 17 insertions, 21 deletions
diff --git a/jpa/plugins/org.eclipse.jpt.jpa.ui/src/org/eclipse/jpt/jpa/ui/details/JpaDetailsProvider.java b/jpa/plugins/org.eclipse.jpt.jpa.ui/src/org/eclipse/jpt/jpa/ui/details/JpaDetailsProvider.java
index a7c11cf787..e9427862c1 100644
--- a/jpa/plugins/org.eclipse.jpt.jpa.ui/src/org/eclipse/jpt/jpa/ui/details/JpaDetailsProvider.java
+++ b/jpa/plugins/org.eclipse.jpt.jpa.ui/src/org/eclipse/jpt/jpa/ui/details/JpaDetailsProvider.java
@@ -1,5 +1,5 @@
/*******************************************************************************
- * Copyright (c) 2006, 2009 Oracle. All rights reserved.
+ * Copyright (c) 2006, 2012 Oracle. All rights reserved.
* This program and the accompanying materials are made available under the
* terms of the Eclipse Public License v1.0, which accompanies this distribution
* and is available at http://www.eclipse.org/legal/epl-v10.html.
@@ -14,37 +14,33 @@ import org.eclipse.jpt.jpa.core.JpaStructureNode;
import org.eclipse.swt.widgets.Composite;
/**
- * This provider is responsible to create the {@link JpaDetailsPage}
- * responsible to show the information for a given content node id.
- *
- * @see JpaDetailsPage
- *
- * @version 3.0
- * @since 2.0
- *
+ * This provider is responsible for creating the {@link JpaDetailsPageManager}
+ * responsible for showing the information for a structure node ID.
+ * <p>
* Provisional API: This interface is part of an interim API that is still
* under development and expected to change significantly before reaching
* stability. It is available at this early stage to solicit feedback from
* pioneering adopters on the understanding that any code that uses this API
* will almost certainly be broken (repeatedly) as the API evolves.
+ *
+ * @version 3.0
+ * @since 2.0
+ *
+ * @see JpaDetailsPageManager
*/
-public interface JpaDetailsProvider
-{
+public interface JpaDetailsProvider {
/**
* Return whether this provider returns a details page for the given structure node
*/
boolean providesDetails(JpaStructureNode structureNode);
-
+
/**
- * Creates a new details page based on the given content node id.
- *
- * @param parent The parent container
- * @param contentNodeId The unique identifier used to determine which details
- * page to create
- * @param widgetFactory The factory used to create various widgets
+ * Build a new details page manager with the specified parent and widget
+ * factory.
*/
- //TODO Should we pass in JpaUiFactory so these pages can be built using the factory and overriden?
- JpaDetailsPage<? extends JpaStructureNode> buildDetailsPage(
+ // TODO pass in JpaUiFactory so these pages can be built using the factory and overridden?
+ JpaDetailsPageManager<? extends JpaStructureNode> buildDetailsPageManager(
Composite parent,
WidgetFactory widgetFactory);
}
@@ -14,37 +14,33 @@ import org.eclipse.jpt.jpa.core.JpaStructureNode;
/**
- * Return whether this provider returns a details page for the given structure node
+ * Return whether the provider can build a details page manager for the
+ * specified JPA structure node.
*/
boolean providesDetails(JpaStructureNode structureNode);

Back to the top